=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format follows the recommendations of
`Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_, and adapts the
markup language to use reStructuredText.

This projects adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.


Unreleased_
===========


0.0.1 -- 2018-07-27
===================

Added
-----

- [code] CLI interface.
- [code] Validation logic for linking matrix.
- [code] Optimization logic to minimize template height.
- [code] SVG drawing logic.
- [doc] Example input matrices: elementary matrices of size 5 and 6.


.. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. .. ..

.. links to git diffs

.. _Unreleased: https://gitlab.uni.lu/PCOG/cate/compare/v0.0.1...master
